﻿-- Author      : RisM
-- Create Date : 6/28/2009 3:54:18 PM

SpeakinSpell = LibStub("AceAddon-3.0"):GetAddon("SpeakinSpell")
local L	= LibStub("AceLocale-3.0"):GetLocale("SpeakinSpell", false)

-------------------------------------------------------------------------------
-- UTILITY FUNCTIONS
-------------------------------------------------------------------------------


-- create a deep copy of the table and return it
function SpeakinSpell:CopyTable(SourceTable)
	local dest = {} -- make a new table in 'dest'
	for k,v in pairs(SourceTable) do
		-- dig into embedded tables to copy those too, not just create references
		if type(v) == "table" then
			dest[k] = self:CopyTable(v)
		else
			dest[k] = v
		end
	end
	return dest
end


function SpeakinSpell:GetDefaultTarget()
	-- try the currently selected target
	local target = UnitName("target")
	if target then
		self:DebugMsg(nil,"<target> is unknown, using selected:"..target)
		return target
	end
	
	-- nobody is selected, try focus
	target = UnitName("focus")
	if target then
		self:DebugMsg(nil,"<target> is unknown, using focus:"..target)
		return target
	end
	
	-- assume self-cast ability
	target = UnitName("player")
	self:DebugMsg(nil,"<target> is unknown, using self:"..target)
	
	return target
end


function SpeakinSpell:ShowOptions()
	-- this is probably not necessary, but make sure this is up to date before opening the options panel
	self:CurrentMessagesGUI_Refresh()
	
	-- open interface options to show SpeakinSpell
	InterfaceOptionsFrame_OpenToCategory(L["SpeakinSpell"])
end


function SpeakinSpell:ShowHelp()
	-- this is probably not necessary, but make sure this is up to date before opening the options panel
	self:CurrentMessagesGUI_Refresh()
	
	-- open interface options to show SpeakinSpell
	InterfaceOptionsFrame_OpenToCategory(L["SpeakinSpell Help"])
end


function SpeakinSpell:ShowCreateNew()
	-- this is probably not necessary, but make sure this is up to date before opening the options panel
	self:CurrentMessagesGUI_Refresh()
	
	-- open interface options to show SpeakinSpell
	InterfaceOptionsFrame_OpenToCategory(L["Create New..."])
end


function SpeakinSpell:ShowMessageOptions()
	-- this is probably not necessary, but make sure this is up to date before opening the options panel
	self:CurrentMessagesGUI_Refresh()
	
	-- open interface options to show SpeakinSpell
	InterfaceOptionsFrame_OpenToCategory(L["Message Settings TITLE"])
end


function SpeakinSpell:TitleCase(s)
	local first = string.sub(s,1,1)
	local rest = string.sub(s,2,-1)

	first = string.upper(first)
	
	rest = string.gsub(rest, " %a",
		function(match) 
			return string.upper(match)
		end
	)
	
	local result = first..rest
	return result
end


function SpeakinSpell:StartsWith(s, prefix)
	start = string.sub(s, 1, string.len(prefix))
	return (start == prefix)
end


function SpeakinSpell:EndsWith(s, suffix)
	strend = string.sub(s, -1 * string.len(suffix))
	return (strend == suffix)
end

